/*
 * Copyright (c) 2017 deltaDNA Ltd. All rights reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.deltadna.android.sdk.notifications;

import java.io.Serializable;
import java.util.Locale;

/**
 * Class representing information on a posted notification.
 */
public class NotificationInfo implements Serializable {
    
    /**
     * The id of the posted notification.
     */
    public final int id;
    /**
     * The push message that triggered the notification.
     */
    public final PushMessage message;
    
    /**
     * Creates a new instance.
     *
     * @param id        the id of the posted notification
     * @param message   the push message that triggered the notification
     */
    NotificationInfo(int id, PushMessage message) {
        this.id = id;
        this.message = message;
    }
    
    @Override
    public String toString() {
        return String.format(
                Locale.US,
                "%s{id: %d, message: %s}",
                getClass().getSimpleName(),
                id,
                message);
    }
}
